; File:         pas.inc
; Author:       RuiLoureiro
; Date:         4 /Set /2001
; 
; Action:
;        Prints the buffer pointed by ESI at line EDX, column EBX with colour attribute EAX.
;        The length of the buffer is ECX
;
; Input:
;        ESI   - Buffer string pointer
;        ECX   - buffer's length
;        EDX   - initial line
;        EBX   - initial column
;        EAX   - colour attribute
;
; Output:
;        clc:  Ok
;              
;        stc:  system error 
;  
; Info:
;       _COLLINCur     = current cursor location
;       _hScreenBuffer = screen buffer handle
;
BufferPrint         proc    
                    LOCAL   wRCLStr:DWORD
                    ;
                    invoke   CursorColorSet, edx, ebx, eax
                    or       ecx, ecx
                    jz       short @F
                    ;
                    invoke  WriteConsole, _hScreenBuffer,       ; handle
                                          esi,                  ; print buffer
                                          ecx,                  ; write ECX char
                                          ADDR wRCLStr,         ; Number written
                                          0                     ;
                    cmp    eax, 0
                    jnz    short @F
                    ;
                    stc
                    ret
                    ;
@@:                 clc
                    ret
BufferPrint         endp
; 
; Action:
;        Prints the Pascal string pointed by pPASStr at (nLin, nCol) with Atr
;
; Input:
;       pPAS     - Pascal string pointer
;        nLin    - initial line
;        nCol    - initial column
;        Atr     - colour Attribute
;
; Output:
;        clc:  Ok
;              
;        stc:  system error 
;
; Info:
;       _COLLINCur     = current cursor location
;       _hScreenBuffer = screen buffer handle
;
PASPrint            proc    pPAS:DWORD, nLin:DWORD, nCol:DWORD, Atr:DWORD
                    pushad
                    ;
                    mov     esi, dword ptr pPAS
                    mov     ecx, dword ptr [esi - $PasLen$]
                    ;
                    mov     edx, nLin
                    mov     ebx, nCol
                    mov     eax, Atr
                    call    BufferPrint
                    ;
                    popad
                    ret
PASPrint            endp
; ---------------------------------------------------------------------------------------------
; Action:
;        Prints the table of Pascal strings with ( LIN, COL, Atr)
;
; Input:
;        pTbl    - Table of Pascal strings
;
; Info:
;       _COLLINCur     = current cursor location
;       _hScreenBuffer = screen buffer handle
;
PASPrintTbl         proc  pTbl:DWORD
                    pushad
                    ;
                    mov    esi, pTbl
                    mov    ecx, dword ptr [esi - $HTbl$]
                    or     ecx, ecx
                    jz     short _ePASPrintTbl
                    ;
                    xor    ebx, ebx
                    ;
_PASPrintTbl0:      push   ebx 
                    push   ecx 
                    push   esi
                        ;
                        cld
                        shl   ebx, 4
                        add   esi, ebx
                        ;
                        lodsd
                        mov   ecx, eax             ; pTbl
                        lodsd
                        mov   edx, eax             ; Lin
                        lodsd
                        mov   ebx, eax             ; Col
                        lodsd                      ; Colour
                        ;
                        mov     esi, ecx
                        mov     ecx, dword ptr [esi - $PasLen$]
                        call    BufferPrint
                        ;
                    pop    esi 
                    pop    ecx 
                    pop    ebx
                    ;
_PASPrintTbl1:      inc    ebx
                    loop   short _PASPrintTbl0
                    ;
_ePASPrintTbl:      popad
                    ret
PASPrintTbl         endp
; ---------------------------------------------------------------------------------------------
; Action:
;        Prints the Pascal string pointed by pPASStr and the nat number EAX in column nCol2
;
; Input:
;       EAX     - number to print after msg
;       nLin    - line
;       nCol1   - column Pascal str
;       nCol2   - column Nat number
;
; Info:
;       _COLLINCur = LIN+COL dword
;
PASDNatPrint        proc pPASStr:DWORD, nLin:DWORD, nCol1:DWORD, nCol2:DWORD, Atr:DWORD    
                    pushad
                    ;
                    invoke   DNatCnvRcl, ADDR _MsgCnvNumber
                    ;
                    mov      ebx, pPASStr
                    invoke   PASPrint, ebx, nLin, nCol1, Atr
                    ;
                    mov      ebx, offset _MsgCnvNumber
                    invoke   RCLClnPrint, nLin, nCol2, Atr
                    ;
                    popad
                    ret
PASDNatPrint        endp
; ---------------------------------------------------------------------------------------------
; Action:
;        Prints the Pascal string pointed by pPASStr and the hexa number EAX in column nCol2
;
; Input:
;       EAX     - number to print after msg
;       nLin    - line
;       nCol1   - column Pascal str
;       nCol2   - column Nat number
;
; Info:
;       _COLLINCur = LIN+COL dword
;
PASDHexPrint        proc pPASStr:DWORD, nLin:DWORD, nCol1:DWORD, nCol2:DWORD, Atr:DWORD    
                    pushad
                    ;
                    invoke   DHexCnvRcl, ADDR _MsgCnvNumber 
                    ;
                    mov      ebx, pPASStr
                    invoke   PASPrint, ebx, nLin, nCol1, Atr
                    ;
                    mov      ebx, offset _MsgCnvNumber
                    invoke   RCLClnPrint, nLin, nCol2, Atr
                    ;
                    popad
                    ret
PASDHexPrint        endp
; ---------------------------------------------------------------------------------------------
; Action:
;        Prints the Pascal string pointed by pPASStr and the hexa number AX in column nCol2
;
; Input:
;       AX      - number to print after msg
;       nLin    - line
;       nCol1   - column Pascal str
;       nCol2   - column Nat number
;
; Info:
;       _COLLINCur = LIN+COL dword
;
PASHexPrint         proc pPASStr:DWORD, nLin:DWORD, nCol1:DWORD, nCol2:DWORD, Atr:DWORD    
                    pushad
                    ;
                    invoke   HexCnvRcl, ADDR _MsgCnvNumber 
                    ;
                    mov      ebx, pPASStr
                    invoke   PASPrint, ebx, nLin, nCol1, Atr
                    ;
                    mov      ebx, offset _MsgCnvNumber
                    invoke   RCLClnPrint, nLin, nCol2, Atr
                    ;
                    popad
                    ret
PASHexPrint         endp
; 

